otcextensions.sdk.cbr.v3.task
===============================

.. automodule:: otcextensions.sdk.cbr.v3.task

The CBR Task Class
--------------------

The ``Task`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.cbr.v3.task.Task
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ErrorInfoSpec
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoBackup
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoCommon
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoDelete
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoSync
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoRestore
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoVaultDelete
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ResourceSpec
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtendInfoRemoveResources
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.task.ExtraInfoSpec
   :members:
